summaryrefslogtreecommitdiffstats
path: root/src/usr/trace/compdesc.C
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/trace/compdesc.C')
-rw-r--r--src/usr/trace/compdesc.C38
1 files changed, 28 insertions, 10 deletions
diff --git a/src/usr/trace/compdesc.C b/src/usr/trace/compdesc.C
index 9e1d77bea..72c7a2476 100644
--- a/src/usr/trace/compdesc.C
+++ b/src/usr/trace/compdesc.C
@@ -5,7 +5,9 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* COPYRIGHT International Business Machines Corp. 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2015 */
+/* [+] International Business Machines Corp. */
+/* */
/* */
/* Licensed under the Apache License, Version 2.0 (the "License"); */
/* you may not use this file except in compliance with the License. */
@@ -94,19 +96,35 @@ namespace TRACE
}
#ifndef __HOSTBOOT_RUNTIME // TODO: RTC 79408
- // Check for special SCAN component to force enable debug trace on.
- if (l_rc && !l_rc->iv_debugEnabled &&
- (0 == memcmp(l_compName, "SCAN", 5)))
+ // Check for special SCAN and FAPI_MFG component to
+ // force enable debug trace on.
+ if (l_rc && !l_rc->iv_debugEnabled)
{
- TARGETING::Target* sys = NULL;
- TARGETING::targetService().getTopLevelTarget(sys);
+ if(0 == memcmp(l_compName, "SCAN", 5))
+ {
+ TARGETING::Target* sys = NULL;
+ TARGETING::targetService().getTopLevelTarget(sys);
- TARGETING::HbSettings hbSettings =
- sys->getAttr<TARGETING::ATTR_HB_SETTINGS>();
+ TARGETING::HbSettings hbSettings =
+ sys->getAttr<TARGETING::ATTR_HB_SETTINGS>();
- if (hbSettings.traceScanDebug)
+ if (hbSettings.traceScanDebug)
+ {
+ l_rc->iv_debugEnabled = true;
+ }
+ }
+ else if(0 == memcmp(l_compName, "FAPI_MFG",9))
{
- l_rc->iv_debugEnabled = true;
+ TARGETING::Target* sys = NULL;
+ TARGETING::targetService().getTopLevelTarget(sys);
+
+ TARGETING::ATTR_MFG_TRACE_ENABLE_type l_mfgTraceEnable =
+ sys->getAttr<TARGETING::ATTR_MFG_TRACE_ENABLE>();
+
+ if (l_mfgTraceEnable)
+ {
+ l_rc->iv_debugEnabled = true;
+ }
}
}
#endif
OpenPOWER on IntegriCloud